@@ -17,7 +17,7 @@ pub trait FloatExt {
 }
 
 impl FloatExt for f32 {
-    fn step(self, edge: f32) -> f32 {
+    fn step(self, edge: Self) -> Self {
         if self < edge {
             0.0
         } else {
@@ -25,7 +25,7 @@ impl FloatExt for f32 {
         }
     }
 
-    fn step_select(self, edge: f32, less: f32, greater_or_equal: f32) -> f32 {
+    fn step_select(self, edge: Self, less: Self, greater_or_equal: Self) -> Self {
         if self < edge {
             less
         } else {
@@ -34,11 +34,11 @@ impl FloatExt for f32 {
     }
 
     #[allow(clippy::suboptimal_flops)]
-    fn lerp(self, other: f32, a: f32) -> f32 {
+    fn lerp(self, other: Self, a: Self) -> Self {
         self + (other - self) * a
     }
 
-    fn saturate(self) -> f32 {
+    fn saturate(self) -> Self {
         self.clamp(0.0, 1.0)
     }
 }
