@@ -73,7 +73,8 @@
 #![warn(
     clippy::flat_map_option,
     clippy::disallowed_method,
-    clippy::disallowed_type
+    clippy::disallowed_type,
+    clippy::single_match_else
 )]
 // END - Ark-specific lints
 
