@@ -8,6 +8,9 @@ use num_traits::Float;
 ///
 /// Adds additional functionality to [`Vec3`] that [`glam`] doesn't have.
 pub trait Vec3Ext {
+    /// For element `i` of `self`, return `v[i].trunc()`
+    fn trunc(self) -> Self;
+
     /// For element `i` of the return value, returns 0.0 if `v[i] < edge[i]` and 1.0 otherwise.
     fn step(self, edge: Self) -> Self;
 
@@ -28,7 +31,13 @@ pub trait Vec3Ext {
 }
 
 impl Vec3Ext for Vec3 {
-    fn step(self, edge: Self) -> Self {
+    /// For element `i` of `self`, return `v[i].trunc()`
+    #[inline]
+    fn trunc(self) -> Self {
+        vec3(self.x.trunc(), self.y.trunc(), self.z.trunc())
+    }
+
+    fn step(self, edge: Vec3) -> Self {
         vec3(
             self.x.step(edge.x),
             self.y.step(edge.y),
